==> open-xchange-gui_6.14.0.0.orig.tar.gz: open-xchange-gui-6.14.0.0/js/subwindow.js <==
if(window.opener)
var corewindow=window.opener.corewindow;
else corewindow = null;
oxThemeStyle = corewindow.oxThemeStyle;
function ErrorPopup() {}
ErrorPopup.ok = function () {
	ErrorPopup.closeWindow();
}
ErrorPopup.openWindow = function () {
	showNode("disable_background_window");
	$("disable_background_window").style.display="block";
	showNode("error_popup");
	centerPopupWindow($("error_popup"));
	$("error_popup").style.display="block";
}
ErrorPopup.closeWindow = function () {
	hideNode("error_popup");
	$("error_popup").style.display="none";	
	hideNode("disable_background_window");
	$("disable_background_window").style.display="none";
}
register("Loaded",function() {
    var newPath = corewindow.oxThemeStyle.path || "default";
    for (var i in init.images) {
        init.images[i] = init.images[i].replace(/\/default\//g, "/"+newPath+"/");
    }
	addOnClose($("error_popup"),function() { ErrorPopup.closeWindow() }); 
	appendNode("everything");
});
function addHideTreeNode(node,parent,index) {
}
function appendNode(id,cd) {
	var node=document.getElementById(id);
	if(!cd && (node.style.display=="none" || node.style.display=="NONE")) {
		if(node.tagName == "DIV") { node.style.display = "block"; }
		else { node.style.display = ""; }
	}
}
function removeNode(id,cd) {
	var node=document.getElementById(id);
	if(!cd && (node.style.display!="none" || node.style.display!="NONE")) {
		node.style.display = "none";
	}	
}
function refillImages(id) {
    if($ALL(id)) {
        var elements=$ALL(id).getElementsByTagName("img");
        for(var i=0;i<elements.length;i++) {
            var src = init.images[elements[i].id];
            if(src && src != elements[i].src) elements[i].src = src;
        }
    }
}
function showNode(id,changedisplay) {
	appendNode(id,changedisplay);
	refillImages(id);
}

function hideNode(id,changedisplay) {
	removeNode(id,changedisplay);
}
var fileloaded=function() {};

function autorefill() {
	var effectsarray1=["menu_global_attachments","menu_mail","menu_mail2","menu_task_new_participant","menu_calendar_new_attachment","menu_dyn_window","menu_contact_new_picture","menu_new_contact_distributionlist","menu_calendar_new_participant","menu_new_mail","menu_mail_new_attachment","menu_new_mail_view"];
	var effectsarray2=["menu_global_tags"];
	var singlearray1=[];
	var singlearray2=["menu_small_mail","menu_small_calendar","menu_small_contacts",
				      "menu_small_distributionlist","menu_small_tasks","menu_small_infostore"];
	var singlearray3=["menu_big_portal","menu_big_mail","menu_big_calendar","menu_big_contacts","menu_big_tasks","menu_big_infostore","menu_big_save","menu_mail_save"];
						  
	if(configGetKey("gui.effects.global")) {
		for(var zaehler=0;zaehler<effectsarray1.length;zaehler++) {
			makeButtonElement1($ALL(effectsarray1[zaehler]));
		}
		for(var zaehler=0;zaehler<effectsarray2.length;zaehler++) {
			makeButtonElement2($ALL(effectsarray2[zaehler]));
		}
		for(var zaehler=0;zaehler<singlearray1.length;zaehler++) {
			setDOMMenuElement1($ALL(singlearray1[zaehler]));
		}
		for(var zaehler=0;zaehler<singlearray2.length;zaehler++) {
			setDOMMenuElement2($ALL(singlearray2[zaehler]));
		}
		for(var zaehler=0;zaehler<singlearray3.length;zaehler++) {
			setDOMMenuElement3($ALL(singlearray3[zaehler]));
		}
	}
	refillImages("menu_options_menu");
	refillImages("body");
}

register("Loaded",autorefill);
register("Loaded",menuLoad);
function menuLoad() {
	setTimeout(function() {
		menuiteration=configGetKey("gui.menu.menuiteration") || 4;
		triggerEvent("OX_menu_Change_Height",true);
	},0);
}

==> open-xchange-gui_6.18.0.0.orig.tar.gz: open-xchange-gui-6.18.0.0/js/subwindow.js <==

// get reference to core window
var corewindow = null;
if (window.opener) {
    corewindow = window.opener.corewindow;
} else if (window.parent) {
    corewindow = window.parent.corewindow;
}
oxThemeStyle = corewindow.oxThemeStyle;
function ErrorPopup() {}
ErrorPopup.ok = function () {
	ErrorPopup.closeWindow();
};
ErrorPopup.openWindow = function () {
    ox.api.setModal(true);
//	showNode("modal-dialog");
//	$("modal-dialog").style.display="block";
	showNode("error_popup");
	centerPopupWindow($("error_popup"));
	$("error_popup").style.display="block";
};
ErrorPopup.closeWindow = function () {
	hideNode("error_popup");
	$("error_popup").style.display="none";
	ox.api.setModal(false);
//	hideNode("modal-dialog");
//	$("modal-dialog").style.display="none";
};
register("Loaded",function() {
    var newPath = corewindow.oxThemeStyle.path || "default";
    for (var i in init.images) {
        init.images[i] = init.images[i].replace(/\/default\//g, "/"+newPath+"/");
    }
	addOnClose($("error_popup"),function() { ErrorPopup.closeWindow(); }); 
	appendNode("everything");
});
function addHideTreeNode(node,parent,index) {
}
function appendNode(id,cd) {
	var node=document.getElementById(id);
	if(node && !cd && (node.style.display=="none" || node.style.display=="NONE")) {
		if(node.tagName == "DIV") { node.style.display = "block"; }
		else { node.style.display = ""; }
	}
}
function removeNode(id,cd) {
	var node=document.getElementById(id);
	if(node && !cd && (node.style.display!="none" || node.style.display!="NONE")) {
		node.style.display = "none";
	}	
}
function refillImages(id) {
    if($ALL(id)) {
        var elements=$ALL(id).getElementsByTagName("img");
        for(var i=0;i<elements.length;i++) {
            var src = init.images[elements[i].id];
            if(src && src != elements[i].src) elements[i].src = src;
        }
    }
}
function showNode(id,changedisplay) {
	appendNode(id,changedisplay);
	refillImages(id);
}

function hideNode(id,changedisplay) {
	removeNode(id,changedisplay);
}
var fileloaded=function() {};

function autorefill() {
	var effectsarray1=["menu_global_attachments","menu_mail","menu_mail2","menu_task_new_participant","menu_calendar_new_attachment","menu_dyn_window","menu_contact_new_picture","menu_new_contact_distributionlist","menu_calendar_new_participant","menu_new_mail","menu_mail_new_attachment","menu_new_mail_view"];
	var effectsarray2=["menu_global_tags"];
	var singlearray1=[];
	var singlearray2=["menu_small_mail","menu_small_calendar","menu_small_contacts",
				      "menu_small_distributionlist","menu_small_tasks","menu_small_infostore"];
	var singlearray3=["menu_big_portal","menu_big_mail","menu_big_calendar","menu_big_contacts","menu_big_tasks","menu_big_infostore","menu_big_save","menu_mail_save"];
						  
	if(configGetKey("gui.effects.global")) {
		for(var zaehler=0;zaehler<effectsarray1.length;zaehler++) {
			makeButtonElement1($ALL(effectsarray1[zaehler]));
		}
		for(var zaehler=0;zaehler<effectsarray2.length;zaehler++) {
			makeButtonElement2($ALL(effectsarray2[zaehler]));
		}
		for(var zaehler=0;zaehler<singlearray1.length;zaehler++) {
			setDOMMenuElement1($ALL(singlearray1[zaehler]));
		}
		for(var zaehler=0;zaehler<singlearray2.length;zaehler++) {
			setDOMMenuElement2($ALL(singlearray2[zaehler]));
		}
		for(var zaehler=0;zaehler<singlearray3.length;zaehler++) {
			setDOMMenuElement3($ALL(singlearray3[zaehler]));
		}
	}
	refillImages("menu_options_menu");
	refillImages("body");
}

register("Loaded",autorefill);
register("Loaded",menuLoad);
function menuLoad() {
	setTimeout(function() {
		menuiteration=configGetKey("gui.menu.menuiteration") || 4;
		triggerEvent("OX_menu_Change_Height",true);
	},0);
}
